api.documents.v1.document.test_helpers.document package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.document.test_helpers.document package

## Submodules

## api.documents.v1.document.test_helpers.document.commit_document module

`api.documents.v1.document.test_helpers.document.commit_document.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/commit, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.commit_document.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/commit, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.commit_document.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/commit, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.commit_document.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/commit, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.get_document_content_by_id module

`api.documents.v1.document.test_helpers.document.get_document_content_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/content, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.get_document_content_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/content, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.get_document_content_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/content, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.get_document_content_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/content, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.get_document_revisions module

`api.documents.v1.document.test_helpers.document.get_document_revisions.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/versions, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.get_document_revisions.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/versions, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.get_document_revisions.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/versions, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.get_document_revisions.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/versions, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.get_meta_info_by_id module

`api.documents.v1.document.test_helpers.document.get_meta_info_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.get_meta_info_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.get_meta_info_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.get_meta_info_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.grant_document_access module

`api.documents.v1.document.test_helpers.document.grant_document_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.grant_document_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.grant_document_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.grant_document_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.list_document_access module

`api.documents.v1.document.test_helpers.document.list_document_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.list_document_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.list_document_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.list_document_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.lock_document module

`api.documents.v1.document.test_helpers.document.lock_document.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/lock, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.lock_document.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/lock, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.lock_document.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/lock, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.lock_document.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/lock, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.revoke_document_access module

`api.documents.v1.document.test_helpers.document.revoke_document_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access/w+, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.revoke_document_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access/w+, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.revoke_document_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access/w+, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.revoke_document_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access/w+, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.update_document module

`api.documents.v1.document.test_helpers.document.update_document.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.update_document.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.update_document.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.update_document.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+, respond with HTTP 401

## api.documents.v1.document.test_helpers.document.update_document_access_settings module

`api.documents.v1.document.test_helpers.document.update_document_access_settings.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 403

`api.documents.v1.document.test_helpers.document.update_document_access_settings.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 404

`api.documents.v1.document.test_helpers.document.update_document_access_settings.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 200

`api.documents.v1.document.test_helpers.document.update_document_access_settings.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/documents/v1/document/w+/access, respond with HTTP 401

## Module contents